diff --git a/src/app.html b/src/app.html index 0a8eee3e0..468e95de3 100644 --- a/src/app.html +++ b/src/app.html @@ -1,5 +1,5 @@ - +
diff --git a/src/routes/__layout.svelte b/src/routes/__layout.svelte index 605413d8d..6bf1e2013 100644 --- a/src/routes/__layout.svelte +++ b/src/routes/__layout.svelte @@ -29,7 +29,16 @@ $: { if (browser) { - document.body.setAttribute('class', `theme-${$app.theme}`); + if ($app.theme === 'auto') { + const darkThemeMq = window.matchMedia('(prefers-color-scheme: dark)'); + if (darkThemeMq.matches) { + document.body.setAttribute('class', `theme-dark`); + } else { + document.body.setAttribute('class', `theme-light`); + } + } else { + document.body.setAttribute('class', `theme-${$app.theme}`); + } } } diff --git a/src/routes/console/[project]/__layout.svelte b/src/routes/console/[project]/__layout.svelte index 09d3c3a5e..d6da7f61b 100644 --- a/src/routes/console/[project]/__layout.svelte +++ b/src/routes/console/[project]/__layout.svelte @@ -26,18 +26,22 @@ } if (browser) { sdkForConsole.subscribe- {membership.name} - {membership.email} + {membership.userName} + {membership.userEmail}
diff --git a/src/sdk.ts b/src/sdk.ts
index ec2e7779d..5c6dc1b33 100644
--- a/src/sdk.ts
+++ b/src/sdk.ts
@@ -1130,18 +1130,22 @@ namespace Models {
* User ID.
*/
userId: string;
+ /**
+ * User name.
+ */
+ userName: string;
+ /**
+ * User email address.
+ */
+ userEmail: string;
/**
* Team ID.
*/
teamId: string;
/**
- * User name.
+ * Team name.
*/
- name: string;
- /**
- * User email address.
- */
- email: string;
+ teamName: string;
/**
* Date, the user has been invited to join the team in Unix timestamp.
*/
@@ -1335,9 +1339,9 @@ namespace Models {
*/
statusCode: number;
/**
* The script stdout output string. Logs the last 4,000 characters of the execution stdout output.
*/
- stdout: string;
+ response: string;
/**
* The script stderr output string. Logs the last 4,000 characters of the execution stderr output
*/
@@ -1435,6 +1439,14 @@ namespace Models {
* Apple OAuth secret ID.
*/
providerAppleSecret: string;
+ /**
+ * Auth0 OAuth app ID.
+ */
+ providerAuth0Appid: string;
+ /**
+ * Auth0 OAuth secret ID.
+ */
+ providerAuth0Secret: string;
/**
* BitBucket OAuth app ID.
*/
@@ -1531,6 +1543,14 @@ namespace Models {
* Notion OAuth secret ID.
*/
providerNotionSecret: string;
+ /**
+ * Okta OAuth app ID.
+ */
+ providerOktaAppid: string;
+ /**
+ * Okta OAuth secret ID.
+ */
+ providerOktaSecret: string;
/**
* PayPal OAuth app ID.
*/
@@ -1596,13 +1616,13 @@ namespace Models {
*/
providerTwitchSecret: string;
/**
* VK OAuth app ID.
*/
- providerVkAppid: string;
+ providerZoomAppid: string;
/**
* VK OAuth secret ID.
*/
- providerVkSecret: string;
+ providerZoomSecret: string;
/**
* Yahoo OAuth app ID.
*/
@@ -2231,31 +2251,31 @@ namespace Models {
/**
* Aggregated stats for number of requests.
*/
- requests: any[];
+ requests: MetricList[];
/**
* Aggregated stats for consumed bandwidth.
*/
- network: any[];
+ network: MetricList[];
/**
* Aggregated stats for function executions.
*/
- functions: any[];
+ functions: MetricList[];
/**
* Aggregated stats for number of documents.
*/
- documents: any[];
+ documents: MetricList[];
/**
* Aggregated stats for number of collections.
*/
- collections: any[];
+ collections: MetricList[];
/**
* Aggregated stats for number of users.
*/
- users: any[];
+ users: MetricList[];
/**
* Aggregated stats for the occupied storage size (in bytes).
*/
- storage: any[];
+ storage: MetricList[];
};
}
@@ -2282,7 +2302,7 @@ type RealtimeRequest = {
};
export type RealtimeResponseEvent
@@ -1335,9 +1339,9 @@ namespace Models {
statusCode: number;
/**
- * The script stdout output string. Logs the last 4,000 characters of the execution stdout output.
+ * The script response output string. Logs the last 4,000 characters of the execution response output.
*/
@@ -1596,13 +1616,13 @@ namespace Models {
providerTwitchSecret: string;
/**
- * VK OAuth app ID.
+ * Zoom OAuth app ID.
*/
@@ -1596,13 +1616,13 @@ namespace Models {
/**
- * VK OAuth secret ID.
+ * Zoom OAuth secret ID.
*/